%% Example_1.m
%
% Simulation of saccade waveforms using a parametric model.
%
% The saccade model corresponds to the 'main sequence' formula
%    Vp = eta*(1 - exp(-A/c))
% where Vp is the peak saccadic velocity and A is the saccadic amplitude.

% Time axis
Fs = 2000;                % sampling rate (samples/sec)
t = -0.1:1/Fs:0.1;        % time axis (sec)

% Main sequence parameters
eta = 600;                % (degree/sec)
c = 6;                    % (no units)

% Saccade parameter
amplitude = 9.5;          % (degree)

% Saccade model
[waveform, velocity, peak_velocity] = saccade_model(t, eta, c, amplitude);

figure(1)
subplot(2,2,1)
plot(1000*t, waveform)
xlabel('Time (ms)')
ylabel('Angle (deg)')
title('Saccade waveform')

subplot(2,2,2)
plot(1000*t, velocity)
xlabel('Time (ms)')
ylabel('Velocity (deg/s)')
title('Saccade velocity')

subplot(2,1,2)
a = 0:0.1:30;
plot(a, eta*(1-exp(-a/c)), amplitude, peak_velocity, '.', 'MarkerSize', 20)
xlabel('Saccade amplitude (deg)')
ylabel('Saccade peak velocity (deg/s)')
title('Main sequence')
legend(sprintf('%.1f(1-e^{-A/%.1f})', eta, c), 'Location', 'SE')

print -dpdf Example_1 

